@@ -48,14 +48,17 @@ from .emerge_fetch import EmergeFetcher, EmergeFetcherError
 
 _ = lambda x: x
 from calculate.lib.cl_lang import (setLocalTranslate, getLazyLocalTranslate)
+
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
+
 class Builder(Update):
     """Основной объект для выполнения действий связанных со сборкой системы
 
     """
-    class Method:
+
+    class Method(object):
         Prepare = "builder_prepare"
         Break = "builder_break"
         Update = "builder_update"
@@ -94,17 +97,20 @@ class Builder(Update):
         @type build:Build
         """
         if build:
-            if isMount(self.clVars.Get('cl_builder_path')):
-                build.close_distributive()
+            builder_path = self.clVars.Get('cl_builder_path')
+            if builder_path:
+                if isMount(builder_path):
+                    build.close_distributive()
             build.remove()
-            if clear:
-                build.distributive.post_clear()
-            pkgdir = self.clVars.Get('cl_builder_pkgdir')
-            if clear_pkg:
-                if '/remote/' in pkgdir:
-                    if path.exists(pkgdir):
-                        removeDir(pkgdir)
-                        Distributive.clear_empty_directories(pkgdir)
+            if builder_path:
+                if clear:
+                    build.distributive.post_clear()
+                pkgdir = self.clVars.Get('cl_builder_pkgdir')
+                if clear_pkg:
+                    if '/remote/' in pkgdir:
+                        if path.exists(pkgdir):
+                            removeDir(pkgdir)
+                            Distributive.clear_empty_directories(pkgdir)
         return True
 
     def restore_build(self, build):
@@ -159,7 +165,7 @@ class Builder(Update):
                                      eq=profile_shortname, limit=1)
         if not profile:
             raise BuilderError(_("Failed to determine profile %s") %
-                              profile_shortname)
+                               profile_shortname)
         chroot_join = lambda x: path.join(chroot_path, x)
         profile_path = path.relpath(profile, chroot_join('etc/portage'))
         try:
@@ -168,13 +174,13 @@ class Builder(Update):
                                  chroot_join('etc/portage/make.profile'))):
                 os.unlink(rm_fn)
             os.symlink(profile_path, chroot_join('etc/portage/make.profile'))
-        except (OSError,IOError) as e:
-            print str(e)
-            raise BuilderError(_("Failed to set the profile: %s")%str(e))
+        except (OSError, IOError) as e:
+            raise BuilderError(_("Failed to set the profile: %s") % str(e))
         return True
 
-    def apply_templates(self,target=None,useClt=None,cltFilter=False,root=None,
-                       useDispatch=True, action="merge", distro_dv=None):
+    def apply_templates(self, target=None, useClt=None, cltFilter=False,
+                        root=None,
+                        useDispatch=True, action="merge", distro_dv=None):
         """
         Применить шаблоны.
 
@@ -187,6 +193,7 @@ class Builder(Update):
         from calculate.lib.cl_template import (TemplatesError,
                                                ProgressTemplate,
                                                templateFunction)
+
         templateFunction.installProg = {}
         templateFunction.installCategory = []
         if target is None:
@@ -217,7 +224,8 @@ class Builder(Update):
                        [pathJoin(chroot, x) for x in clVars.Get('cl_env_path')],
                        force=True)
             clVars.Set('cl_make_profile', path.join(chroot,
-                       'etc/portage/make.profile'), force=True)
+                                                    'etc/portage/make.profile'),
+                       force=True)
             clVars.Set('cl_action', action, force=True)
             clVars.Set('cl_chroot_status', 'on', force=True)
             for copyvar in ("cl_dispatch_conf", "cl_verbose_set",
@@ -226,17 +234,17 @@ class Builder(Update):
 
             clVars.iniCache = {}
             clVars.flIniFile()
-            cltFilter=True if cltFilter in (True,"on") else False
+            cltFilter = True if cltFilter in (True, "on") else False
             clVars.Set("cl_chroot_path", chroot, True)
             clVars.Set("cl_root_path", root, True)
             # определение каталогов содержащих шаблоны
-            dirs_list, files_list = ([],[])
+            dirs_list, files_list = ([], [])
             useClt = useClt in ("on", True)
             self.addProgress()
-            nullProgress = lambda *args,**kw:None
+            nullProgress = lambda *args, **kw: None
             dispatch = self.dispatchConf if useDispatch else None
 
-            clTempl = ProgressTemplate(nullProgress,clVars,
+            clTempl = ProgressTemplate(nullProgress, clVars,
                                        cltObj=useClt,
                                        cltFilter=cltFilter,
                                        printSUCCESS=self.printSUCCESS,
@@ -302,7 +310,7 @@ class Builder(Update):
 
     def _get_log_file(self):
         logname = "build-%s/%s" % (self.clVars.Get('cl_builder_id_path'),
-                                  self.clVars.Get('cl_task_name'))
+                                   self.clVars.Get('cl_task_name'))
         mainlog = self.clVars.Get('core.cl_log_path')
         return path.join(mainlog, logname)
 
@@ -353,9 +361,9 @@ class Builder(Update):
                         return True
                 else:
                     self.printSUCCESS(_("Nothing to merge"))
-            except EmergeError as e:
-                #self.set_need_update(False)
-                #self.emerge_cache.drop_cache("Emerge error")
+            except EmergeError:
+                # self.set_need_update(False)
+                # self.emerge_cache.drop_cache("Emerge error")
                 self._display_install_package(emerge, emergelike=True)
                 self._display_error(emerge.prepare_error)
                 raise
@@ -406,7 +414,7 @@ class Builder(Update):
         with writeFile(self._get_log_file()) as f:
             f.write(p.read())
         if p.failed():
-            raise BuilderError(_("Failed to execute %s")%command)
+            raise BuilderError(_("Failed to execute %s") % command)
         return True
 
     def update_task(self, task_name):
@@ -502,7 +510,8 @@ class Builder(Update):
                     logfile=logfile))) as emerge:
                 emerge.question.default_answer = "n"
                 emerge.run()
-                self.pretend_package_list[atom] = list(emerge.install_packages.list)
+                self.pretend_package_list[atom] = list(
+                    emerge.install_packages.list)
         return self.pretend_package_list[atom]
 
     def _display_video_install_package(self, package_list, drv_name):
@@ -514,8 +523,8 @@ class Builder(Update):
         :param drv_name: имя драйвера (PN)
         :return:
         """
-        #asterisk = self.color_print.bold("*")
-        #ebuild_wrong = TextState.Colors.RED
+        # asterisk = self.color_print.bold("*")
+        # ebuild_wrong = TextState.Colors.RED
         ebuild_color = TextState.Colors.GREEN
         binary_color = TextState.Colors.PURPLE
         output_package_list = ", ".join(
@@ -527,10 +536,9 @@ class Builder(Update):
         wrong_package = any(not x['binary'] and x['PN'] != drv_name
                             for x in package_list)
         if wrong_package:
-            self.printERROR(_("Depends %s")%output_package_list)
+            self.printERROR(_("Depends %s") % output_package_list)
         else:
-            self.printSUCCESS(_("Depends %s")%output_package_list)
-
+            self.printSUCCESS(_("Depends %s") % output_package_list)
 
     def fetch_drivers(self, builder_path, builder_distdir, builder_pkgdir):
         """
@@ -594,13 +602,12 @@ class Builder(Update):
                         raise BuilderError(_("Failed to get %s") % drv_name)
             except EmergeFetcherError as e:
                 if e.extension:
-                    self.printPre("\n%s\n"%e.extension)
+                    self.printPre("\n%s\n" % e.extension)
                 if e.errno == EmergeFetcherError.FetchErrno.NeedManually:
                     raise BuilderError(
                         _("Failed to fetch files for %s") % drv_name)
                 repeat_driver_list.append([drv_name, drv_mask, drv_atom])
 
-
             if not driver_list and repeat_driver_list:
                 driver_list = repeat_driver_list
                 repeat_driver_list = []
@@ -792,7 +799,7 @@ class Builder(Update):
         :return:
         """
         chroot_path = self.clVars.Get('cl_builder_path')
-        os.system('/usr/bin/chroot %s /usr/sbin/emaint binhost -f &>/dev/null'%
+        os.system('/usr/bin/chroot %s /usr/sbin/emaint binhost -f &>/dev/null' %
                   chroot_path)
 
     def cleanpkg(self):
@@ -832,7 +839,7 @@ class Builder(Update):
                 "%s\nKEYWORDS: amd64 x86" % re_keywords.sub('', x)
                 for x in data_blocks[1:] if x.strip()]
             with writeFile(pathPackages) as f:
-                f.write("\n\n".join(data_blocks[:1]+modified_blocks))
+                f.write("\n\n".join(data_blocks[:1] + modified_blocks))
 
     def binaryCleaning(self):
         """Clean binary repository"""
@@ -854,18 +861,20 @@ class Builder(Update):
             if path.exists(dbPkg) and path.exists(pkgDir):
                 # get pkg list from distro
                 pkgList = \
-                    reduce(lambda x,y:x+y,
-                    map(lambda x:map(lambda z:path.join(x,"%s.tbz2"%z),
-                                 os.listdir(path.join(dbPkg,x))),
-                    os.listdir(dbPkg)),[])
+                    reduce(lambda x, y: x + y,
+                           map(lambda x: map(
+                               lambda z: path.join(x, "%s.tbz2" % z),
+                               os.listdir(path.join(dbPkg, x))),
+                               os.listdir(dbPkg)), [])
                 # get binary packages
                 binList = \
-                    reduce(lambda x,y:x+y,
-                    map(lambda x:map(lambda z:path.join(x,z)[len(pkgDir)+1:],
-                                 os.listdir(path.join(x))),
-                    filter(lambda x:path.isdir(x),
-                    map(lambda x:path.join(pkgDir,x),
-                    os.listdir(pkgDir)))),[])
+                    reduce(lambda x, y: x + y,
+                           map(lambda x: map(
+                               lambda z: path.join(x, z)[len(pkgDir) + 1:],
+                               os.listdir(path.join(x))),
+                               filter(lambda x: path.isdir(x),
+                                      map(lambda x: path.join(pkgDir, x),
+                                          os.listdir(pkgDir)))), [])
 
                 # remove files which in binary and not in db/pkg
                 removeList = list(set(binList) - set(pkgList))
@@ -878,12 +887,12 @@ class Builder(Update):
                         removeList))
 
                 # remove empty directories
-                map(lambda x:os.rmdir(x),
-                 filter(lambda x:path.isdir(x) and not os.listdir(x),
-                 map(lambda x:path.join(pkgDir,x),
-                 os.listdir(pkgDir))))
+                map(lambda x: os.rmdir(x),
+                    filter(lambda x: path.isdir(x) and not os.listdir(x),
+                           map(lambda x: path.join(pkgDir, x),
+                               os.listdir(pkgDir))))
 
-                self.regenPackages(chrootPath,pkgDir[len(chrootPath):])
+                self.regenPackages(chrootPath, pkgDir[len(chrootPath):])
         except OSError as e:
             raise BuilderError(str(e))
         return True
@@ -1031,7 +1040,7 @@ class Builder(Update):
                         force=True)
         return True
 
-    def create_dev_nodes(self,directory):
+    def create_dev_nodes(self, directory):
         """Create nodes for dev http://dev.gentoo.org/~a3li/openrc.txt"""
         devPath = path.join(directory, "dev")
         # clean dev
@@ -1062,7 +1071,7 @@ class Builder(Update):
         dv = self.clVars
         if any(search_worked_process2(dv, filter_func=filter_func)):
             raise BuilderError(_("Builder action for %s is already running. "
-                                    "Try to run later.")%build_id)
+                                 "Try to run later.") % build_id)
         return True
 
     def check_chroot_run(self):
@@ -1075,12 +1084,11 @@ class Builder(Update):
         if programs:
             raise BuilderError(
                 _("Chrooted {cmd} has already run into {id}").format(
-                cmd=programs[0].split('\x00')[0],
-                id=self.clVars.Get('cl_builder_id')
-            ))
+                    cmd=programs[0].split('\x00')[0],
+                    id=self.clVars.Get('cl_builder_id')
+                ))
         return True
 
-
     def update_menu(self, dn):
         with IsoDistributive(dn) as iso:
             d = iso.getDirectory()
@@ -1091,6 +1099,7 @@ class Builder(Update):
             self.clVars.getInfo('cl_builder_videodrv_set').autodetect = True
             self.clVars.Invalidate('cl_builder_videodrv_set', force=True)
             from calculate.lib.cl_template import templateFunction
+
             templateFunction.installProg = {}
             templateFunction.installCategory = []
             self.applyTemplates(d, False, False, root_path)
@@ -1107,7 +1116,7 @@ class Builder(Update):
         if path.exists(flashTmp) and not listDirectory(flashTmp):
             try:
                 os.rmdir(flashTmp)
-            except (OSError,IOError) as e:
+            except (OSError, IOError) as e:
                 self.printWARNING(str(e))
         return True
 
@@ -1174,8 +1183,8 @@ class Builder(Update):
                 if listDirectory(old_path):
                     if path.exists(new_path):
                         for fn in listDirectory(old_path):
-                            old_fn = path.join(old_path,fn)
-                            new_fn = path.join(new_path,fn)
+                            old_fn = path.join(old_path, fn)
+                            new_fn = path.join(new_path, fn)
                             if path.exists(new_fn):
                                 os.unlink(new_fn)
                             os.rename(old_fn, new_fn)
