@@ -45,16 +45,6 @@ from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 
 
-def debug(func):
-    @wraps(func)
-    def _wrapped_func(*args, **kw):
-        ret = func(*args, **kw)
-        print "MYDEBUG", ret
-        return ret
-
-    return _wrapped_func
-
-
 def is_action(*available_action, **action_kwargs):
     def decorator(func):
         @wraps(func)
@@ -154,6 +144,7 @@ class VariableClBuilderSourceFilename(Variable):
     opt = ["--source"]
     metavalue = "SOURCE"
     untrusted = True
+    check_after = ["cl_builder_layered_set"]
 
     def init(self):
         self.label = _("Source image")
@@ -163,6 +154,11 @@ class VariableClBuilderSourceFilename(Variable):
         """Set image file"""
         if self.Get('cl_action') in Actions.NewAssemble and not isoimage:
             raise VariableError(_("You need to select a source image"))
+        if self.GetBool('cl_builder_layered_set'):
+            if not isinstance(self.Get('cl_builder_source'),
+                              IsoDistributive):
+                raise VariableError(
+                    _("Wrong source distributive for layered build"))
         shortname = self.Get('os_builder_linux_shortname')
         build = self.Get('os_builder_linux_build')
         arch = self.Get('os_builder_arch_machine')
@@ -249,7 +245,9 @@ class VariableClBuilderDiskDev(Variable):
                     dn = base_name
                 full_dn = path.join(default_path, dn)
                 if ((not path.exists(full_dn) or not isMount(full_dn)) and
-                    ds is None or ds.lock_device(full_dn)):
+                            ds is None or
+                            isinstance(ds, DriveSpool) and
+                            ds.lock_device(full_dn)):
                     return full_dn
             else:
                 return ""
@@ -412,9 +410,12 @@ class VariableClBuilderPath(ReadonlyVariable):
     """
 
     def get(self):
-        image = self.Get('cl_builder_target')
-        if image:
-            return image.getDirectory()
+        try:
+            image = self.Get('cl_builder_target')
+            if image:
+                return image.getDirectory()
+        except DistributiveError:
+            return ""
         return ""
 
 
@@ -560,7 +561,7 @@ class VariableClBuilderPreparedId(BaseBuildId):
         for x in bs:
             build = bs.get_build(x)
             if (build and (action == Actions.Break or
-                           build.status == Build.Status.Worked)):
+                                   build.status == Build.Status.Worked)):
                 yield x
 
     def get(self):
