@@ -22,13 +22,13 @@ from calculate.lib.variables import system as lib_system
 from calculate.update.variables import update
 from calculate.update import profile as update_profile
 
-
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.update.variables.update import DataVarsUpdateProfile
 
 _ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
 
+
 class VariableClBuilderProfileStorage(ReadonlyVariable):
     type = "object"
 
@@ -121,6 +121,7 @@ class VariableClBuilderProfileName(lib_linux.VariableClProfileName):
     def init(self):
         self.label = _("System profile")
 
+
 class VariableClBuilderProfileRepoName(update.VariableClUpdateProfileRepoName):
     """
     Название репозитория
@@ -128,6 +129,7 @@ class VariableClBuilderProfileRepoName(update.VariableClUpdateProfileRepoName):
     storage = "builder.cl_builder_profile_storage"
     url = "builder.cl_builder_profile_url"
 
+
 class VariableClBuilderProfileRepository(
     update.VariableClUpdateProfileRepository):
     """
@@ -147,6 +149,7 @@ class VariableClBuilderTemplatesLocate(update.VariableClUpdateTemplatesLocate):
 
     profile_datevars = "builder.cl_builder_profile_datavars"
 
+
 class VariableClBuilderProfileDatavars(update.VariableClUpdateProfileDatavars):
     type = "object"
 
@@ -159,15 +162,16 @@ class VariableClBuilderProfileDatavars(update.VariableClUpdateProfileDatavars):
         path_profile = self.Select(self.profiles_path,
                                    where=self.profiles_shortname,
                                    eq=profile, limit=1)
-        #print self.Get(self.profiles_path)
-        #print self.Get(self.profiles_shortname)
-        #print profile
+        # print self.Get(self.profiles_path)
+        # print self.Get(self.profiles_shortname)
+        # print profile
         builder_path = self.Get('cl_builder_path')
-        #print "BUILDER_PATH", builder_path
+        # print "BUILDER_PATH", builder_path
         if path_profile:
             return DataVarsUpdateProfile(path_profile, builder_path)
         return ""
 
+
 class VariableClBuilderProfileSystemShortname(
     update.VariableClUpdateProfileSystem):
     """
@@ -183,7 +187,9 @@ class VariableClBuilderProfileSystemShortname(
     url = "builder.cl_builder_profile_url"
     gentoo_arch = 'builder.os_builder_arch_machine_gentoo'
 
-class VariableOsBuilderArchMachineGentoo(lib_system.VariableOsArchMachineGentoo):
+
+class VariableOsBuilderArchMachineGentoo(
+    lib_system.VariableOsArchMachineGentoo):
     """
     Архитектура пакетов
     """
@@ -191,7 +197,7 @@ class VariableOsBuilderArchMachineGentoo(lib_system.VariableOsArchMachineGentoo)
 
 
 class VariableClBuilderProfileLinuxFullname(
-        update.VariableClUpdateProfileLinuxFullname):
+    update.VariableClUpdateProfileLinuxFullname):
     """
     Имя системы в профиле
     """
@@ -199,7 +205,7 @@ class VariableClBuilderProfileLinuxFullname(
 
 
 class VariableClBuilderProfileDependData(
-        update.VariableClUpdateProfileDependData):
+    update.VariableClUpdateProfileDependData):
     """
     Зависимые репозитории
     """
@@ -226,16 +232,19 @@ class VariableClBuilderProfileDependUrl(FieldValue, ReadonlyVariable):
     def init(self):
         self.label = _("URL")
 
+
 class VariableClBuilderProfileSyncRep(ReadonlyVariable):
     type = "list"
 
     def get(self):
         return list(reversed(self.Get('update.cl_update_rep_name')))
 
+
 class VariableClBuilderSyncRep(update.VariableClUpdateSyncRep):
     """
     Обновляемый репозиторий
     """
+
     @property
     def rep_name(self):
         dv = self.Get('cl_builder_linux_datavars')
@@ -243,12 +252,13 @@ class VariableClBuilderSyncRep(update.VariableClUpdateSyncRep):
             return dv.Get('cl_update_rep_name')
         return ""
 
+
 class VariableClBuilderRemoveRep(ReadonlyVariable):
     def get(self):
         dv_builder_linux = self.Get('cl_builder_linux_datavars')
         dv_builder_profile = self.Get('cl_builder_profile_datavars')
         if dv_builder_linux and dv_builder_profile:
             return list(set(dv_builder_linux.Get('cl_update_rep_name')) -
-                    set(dv_builder_profile.Get('cl_update_rep_name')))
+                        set(dv_builder_profile.Get('cl_update_rep_name')))
         else:
             return []
