@@ -25,7 +25,7 @@ from .builder import Builder
 from calculate.update.update import UpdateError
 from .datavars import BuilderError
 from .variables.action import Actions as BuilderActions
-from calculate.lib.utils.portage import GitError
+from calculate.lib.utils.git import GitError
 from utils.cl_builder_prepare import ClBuilderPrepareAction
 from utils.cl_builder_profile import ClBuilderProfileAction
 from utils.cl_builder_break import ClBuilderBreakAction
@@ -33,6 +33,7 @@ from utils.cl_builder_update import ClBuilderUpdateAction
 from utils.cl_builder_restore import ClBuilderRestoreAction
 from utils.cl_builder_image import ClBuilderImageAction
 from utils.cl_builder_menu import ClBuilderMenuAction
+
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
